========
eagleeye
========

EagleEye TE(4)

Installation
------------

Usage:
 * Install external dependencies:
   `sudo apt-get install chromium-browser unzip xvfb`

 * Install chromedriver:
   `curl https://chromedriver.googlecode.com/files/chromedriver_linux64_2.2.zip | funzip > chromedriver
   chmod +x chromedriver
   sudo mv chromedriver /usr/bin/chromedriver`

 * Install eagleeye itself:
   `sudo pip install eagleeye_te`
